@@ -9,10 +9,9 @@ package Lemonldap::NG::Common::Crypto;
 use strict;
 use Crypt::Rijndael;
 use MIME::Base64;
-use bytes;
 use base qw(Crypt::Rijndael);
 
-our $VERSION = '0.99.1';
+our $VERSION = '0.1';
 
 our $msg;
 
@@ -31,16 +30,9 @@ sub new {
 # @param data datas to encrypt
 # @return encrypted datas in Base64 format
 sub encrypt {
-    my ( $self, $str ) = @_;
+    my $self = shift;
     my $tmp;
-    eval {
-        $tmp = encode_base64(
-            $self->SUPER::encrypt(
-                $str . "\0" x ( 16 - bytes::length($str) % 16 )
-            ),
-            ''
-        );
-    };
+    eval { $tmp = encode_base64( $self->SUPER::encrypt(@_), '' ); };
     if ($@) {
         $msg = "Crypt::Rijndael error : $@";
         return undef;
@@ -68,10 +60,6 @@ sub decrypt {
     }
     else {
         $msg = '';
-
-        # Obscure Perl re bug...
-        $tmp .= "\0";
-        $tmp =~ s/\0*$//;
         return $tmp;
     }
 }
